#include <stdio.h>
#include <stdlib.h>
#include "yatable_keyinfo.h"

int usage(char* argv)
{
    fprintf(stderr, "Usage: %s <OPTION> <KEYINFO>\n", argv);
    fprintf(stderr, "\t [-n|--keyname]\tGet KeyName by KeyCode\n");
    fprintf(stderr, "\t [-c|--keycode]\tGet KeyCode by KeyName\n");
    fprintf(stderr, "\t [-k|--modkey]\tGet ModKey by ModState\n");
    fprintf(stderr, "\t [-s|--modstat]\tGet ModState by ModKey\n");
    return 1;
}

int main(int argc, char* argv[])
{
    if(argc != 3) return usage(argv[0]);

    if((strcmp(argv[1], "-n") == 0) ||
            (strcmp(argv[1], "--keyname") == 0)) {
        unsigned int keycode = (unsigned int) atol(argv[2]);
        const char* keyname = YaTableKeyCodeGetKeyName(keycode);

        if(keyname == NULL) keyname = "XK_VoidSymbol";
        printf("val:%u\tcode:0x%x\tname:%s\n", keycode, keycode, keyname);
    } else if((strcmp(argv[1], "-c") == 0) ||
              (strcmp(argv[1], "--keycode") == 0)) {
        const char* keyname = argv[2];
        unsigned int keycode = YaTableKeyNameGetKeyCode(keyname);

        printf("val:%u\tcode:0x%x\tname:%s\n", keycode, keycode, keyname);
    } else if((strcmp(argv[1], "-k") == 0) ||
              (strcmp(argv[1], "--modkey") == 0)) {
        unsigned int modstat = (unsigned int) atol(argv[2]);
        const char* modkey = YaTableModStateGetKeyName(modstat);

        if(modkey == NULL) modkey = "NULL";
        printf("stat:%u\tmodkey:%s\n", modstat, modkey);
    } else if((strcmp(argv[1], "-s") == 0) ||
              (strcmp(argv[1], "--modstat") == 0)) {
        const char* modkey = argv[2];
        unsigned int modstat = YaTableKeyNameGetModState(modkey);

        printf("stat:%u\tmodkey:%s\n", modstat, modkey);
    } else {
        return usage(argv[0]);
    }

    return 0;
}

